#    test_merge_upstream.py -- Blackbox tests for merge-upstream.
#    Copyright (C) 2007 James Westby <jw+debian@jameswestby.net>
#    
#    This file is part of bzr-builddeb.
#
#    bzr-builddeb is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    bzr-builddeb is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with bzr-builddeb; if not, write to the Free Software
#    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
#

import os
import tarfile

from bzrlib.plugins.builddeb.tests import BuilddebTestCase


class TestMergeUpstream(BuilddebTestCase):

  upstream_dir = property(lambda self:
      self.package_name + '-' + self.upstream_version)
  upstream_tarball_name = property(lambda self:
      self.package_name + '_' + self.upstream_version + '.orig.tar.gz')

  def make_unpacked_upstream_source(self):
    os.mkdir(self.upstream_dir)
    files = ['README']
    self.build_tree([os.path.join(self.upstream_dir, filename)
                     for filename in files])

  def make_upstream_tarball(self):
    self.make_unpacked_upstream_source()
    tar = tarfile.open(self.upstream_tarball_name, 'w:gz')
    try:
      tar.add(self.upstream_dir)
    finally:
      tar.close()

  def test_merge_upstream_available(self):
    self.run_bzr('merge-upstream --help')

  def test_merge_upstream_into_empty_branch(self):
    self.make_branch_and_tree('.')
    self.make_upstream_tarball()
    cmd = (
      'merge-upstream %s --package %s --version %s' %
      (self.upstream_tarball_name, self.package_name, self.upstream_version))
    self.run_bzr(cmd)


# vim: ts=2 sts=2 sw=2
